/**
 * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
 * *
 * Copyright (C) 2011, 2012 Loic J. Duros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
 *
 *
 */

/* list generated one time using tools/jslibfetcher.py */

var list = [
    "https://ajax.googleapis.com/ajax/libs/dojo/1.1.1/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.2.0/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.2.3/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.3.0/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.3.1/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.3.2/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.4.0/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.4.1/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.4.3/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.5/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.5.1/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.6/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.6.1/dojo/dojo.xd.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.0/dojo/dojo.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.1/dojo/dojo.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.2/dojo/dojo.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.3/dojo/dojo.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.8.0/dojo/dojo.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.1.1/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.2.0/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.2.3/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.3.0/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.3.1/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.3.2/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.4.0/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.4.1/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.4.3/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.5/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.5.1/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.6/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.6.1/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.0/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.1/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.2/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.7.3/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/dojo/1.8.0/dojo/dojo.xd.js.uncompressed.js",
    "https://ajax.googleapis.com/ajax/libs/ext-core/3.0.0/ext-core.js",
    "https://ajax.googleapis.com/ajax/libs/ext-core/3.1.0/ext-core.js",
    "https://ajax.googleapis.com/ajax/libs/ext-core/3.0.0/ext-core-debug.js",
    "https://ajax.googleapis.com/ajax/libs/ext-core/3.1.0/ext-core-debug.js",
    "http://code.jquery.com/jquery-1.0.pack.js",
    "http://code.jquery.com/jquery-1.0.1.pack.js",
    "http://code.jquery.com/jquery-1.0.1.js",
    "http://code.jquery.com/jquery-1.0.2.pack.js",
    "http://code.jquery.com/jquery-1.0.2.js",
    "http://code.jquery.com/jquery-1.0.3.pack.js",
    "http://code.jquery.com/jquery-1.0.3.js",
    "http://code.jquery.com/jquery-1.0.4.pack.js",
    "http://code.jquery.com/jquery-1.0.4.js",
    "http://code.jquery.com/jquery-1.1.pack.js",
    "http://code.jquery.com/jquery-1.1.js",
    "http://code.jquery.com/jquery-1.1.1.pack.js",
    "http://code.jquery.com/jquery-1.1.1.js",
    "http://code.jquery.com/jquery-1.1.2.pack.js",
    "http://code.jquery.com/jquery-1.1.2.js",
    "http://code.jquery.com/jquery-1.1.3.pack.js",
    "http://code.jquery.com/jquery-1.4.min.js",
    "http://code.jquery.com/jquery-1.4.js",
    "http://code.jquery.com/jquery-1.4.1.min.js",
    "http://code.jquery.com/jquery-1.4.1.js",
    "http://code.jquery.com/jquery-1.4.2.min.js",
    "http://code.jquery.com/jquery-1.4.2.js",
    "http://code.jquery.com/jquery-1.4.3.min.js",
    "http://code.jquery.com/jquery-1.4.4.js",
    "http://code.jquery.com/jquery-1.5.min.js",
    "http://code.jquery.com/jquery-1.5.js",
    "http://code.jquery.com/jquery-1.5.1.min.js",
    "http://code.jquery.com/jquery-1.5.1.js",
    "http://code.jquery.com/jquery-1.5.2.min.js",
    "http://code.jquery.com/jquery-1.5.2.js",
    "http://code.jquery.com/jquery-1.6.min.js",
    "http://code.jquery.com/jquery-1.6.js",
    "http://code.jquery.com/jquery-1.6.1.min.js",
    "http://code.jquery.com/jquery-1.6.1.js",
    "http://code.jquery.com/jquery-1.6.2.min.js",
    "http://code.jquery.com/jquery-1.6.2.js",
    "http://code.jquery.com/jquery-1.6.3.min.js",
    "http://code.jquery.com/jquery-1.6.3.js",
    "http://code.jquery.com/jquery-1.6.4.min.js",
    "http://code.jquery.com/jquery-1.6.4.js",
    "http://code.jquery.com/jquery-1.7.min.js",
    "http://code.jquery.com/jquery-1.7.js",
    "http://code.jquery.com/jquery-1.7.1.min.js",
    "http://code.jquery.com/jquery-1.7.1.js",
    "http://code.jquery.com/jquery-1.7.2.min.js",
    "http://code.jquery.com/jquery-1.7.2.js",
    "http://code.jquery.com/jquery-1.8.0.min.js",
    "http://code.jquery.com/jquery-1.8.0.js",
    "http://code.jquery.com/jquery-1.8.1.min.js",
    "http://code.jquery.com/jquery-1.8.1.js",
    "http://code.jquery.com/jquery-1.8.2.min.js",
    "http://code.jquery.com/jquery-1.8.2.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.1.3.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.1.3.1.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.1.3.1.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.1.4.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.1.4.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.1.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.1.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.1.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.2.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.2.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.2.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.3.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.3.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.3.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.4.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.4.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.4.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.5.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.5.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.5.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.6.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.6.pack.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.2.6.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.3.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.3.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.3.1.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.3.1.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.3.2.min.js",
    "http://jqueryjs.googlecode.com/files/jquery-1.3.2.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.5.2/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.5.3/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.6.0/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.0/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.1/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.2/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.3/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.0/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.1/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.4/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.5/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.6/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.7/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.8/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.9/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.10/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.11/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.12/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.13/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.14/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.15/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.16/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.17/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.18/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.19/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.20/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.21/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.22/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.23/jquery-ui.min.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.5.2/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.5.3/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.6.0/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.0/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.1/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.2/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.7.3/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.0/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.1/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.4/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.5/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.6/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.7/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.8/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.9/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.10/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.11/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.12/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.13/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.14/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.15/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.16/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.17/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.18/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.19/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.20/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.21/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.22/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.23/jquery-ui.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.1.1/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.1.2/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.1/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.2/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.3/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.4/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.5/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.3.0/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.3.1/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.3.2/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.0/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.1/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.2/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.3/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.4/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.5/mootools-yui-compressed.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.1.1/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.1.2/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.1/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.2/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.3/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.4/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.2.5/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.3.0/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.3.1/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.3.2/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.0/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.1/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.2/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.3/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.4/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/mootools/1.4.5/mootools.js",
    "https://ajax.googleapis.com/ajax/libs/prototype/1.6.0.2/prototype.js",
    "https://ajax.googleapis.com/ajax/libs/prototype/1.6.0.3/prototype.js",
    "https://ajax.googleapis.com/ajax/libs/prototype/1.6.1.0/prototype.js",
    "https://ajax.googleapis.com/ajax/libs/prototype/1.7.0.0/prototype.js",
    "https://ajax.googleapis.com/ajax/libs/prototype/1.7.1.0/prototype.js",
    "https://ajax.googleapis.com/ajax/libs/scriptaculous/1.8.1/scriptaculous.js",
    "https://ajax.googleapis.com/ajax/libs/scriptaculous/1.8.2/scriptaculous.js",
    "https://ajax.googleapis.com/ajax/libs/scriptaculous/1.8.3/scriptaculous.js",
    "https://ajax.googleapis.com/ajax/libs/scriptaculous/1.9.0/scriptaculous.js",
    "https://ajax.googleapis.com/ajax/libs/swfobject/2.1/swfobject.js",
    "https://ajax.googleapis.com/ajax/libs/swfobject/2.2/swfobject.js",
    "https://ajax.googleapis.com/ajax/libs/swfobject/2.1/swfobject_src.js",
    "https://ajax.googleapis.com/ajax/libs/swfobject/2.2/swfobject_src.js",
    "https://raw.github.com/documentcloud/underscore/1.3.3/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.3.2/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.3.1/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.3.0/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.2.4/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.2.3/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.2.2/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.2.1/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.2.0/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.7/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.6/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.5/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.4/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.3/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.2/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.1/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.1.0/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.0.4/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.0.3/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.0.2/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.0.1/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.0.0/underscore.js",
    "https://raw.github.com/documentcloud/underscore/1.3.3/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.3.2/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.3.1/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.3.0/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.2.4/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.2.3/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.2.2/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.2.1/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.2.0/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.7/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.6/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.5/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.4/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.3/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.2/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.1/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.1.0/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.0.4/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.0.3/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.0.2/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.0.1/underscore-min.js",
    "https://raw.github.com/documentcloud/underscore/1.0.0/underscore-min.js",
    "http://yui.yahooapis.com/2.6.0/build/yuiloader/yuiloader-min.js",
    "http://yui.yahooapis.com/2.7.0/build/yuiloader/yuiloader-min.js",
    "http://yui.yahooapis.com/2.8.0r4/build/yuiloader/yuiloader-min.js",
    "http://yui.yahooapis.com/2.8.1/build/yuiloader/yuiloader-min.js",
    "http://yui.yahooapis.com/2.8.2/build/yuiloader/yuiloader-min.js",
    "http://yui.yahooapis.com/2.9.0/build/yuiloader/yuiloader-min.js",
    "http://yui.yahooapis.com/2.6.0/build/yuiloader/yuiloader.js",
    "http://yui.yahooapis.com/2.7.0/build/yuiloader/yuiloader.js",
    "http://yui.yahooapis.com/2.8.0r4/build/yuiloader/yuiloader.js",
    "http://yui.yahooapis.com/2.8.1/build/yuiloader/yuiloader.js",
    "http://yui.yahooapis.com/2.8.2/build/yuiloader/yuiloader.js",
    "http://yui.yahooapis.com/2.9.0/build/yuiloader/yuiloader.js",
    "http://yui.yahooapis.com/3.3.0/build/yui-base/yui-base-min.js",
    "http://yui.yahooapis.com/3.4.0/build/yui-base/yui-base-min.js",
    "http://yui.yahooapis.com/3.4.1/build/yui-base/yui-base-min.js",
    "http://yui.yahooapis.com/3.5.0/build/yui-base/yui-base-min.js",
    "http://yui.yahooapis.com/3.5.1/build/yui-base/yui-base-min.js",
    "http://yui.yahooapis.com/3.6.0/build/yui-base/yui-base-min.js",
    "http://yui.yahooapis.com/3.3.0/build/yui-base/yui-base.js",
    "http://yui.yahooapis.com/3.4.0/build/yui-base/yui-base.js",
    "http://yui.yahooapis.com/3.4.1/build/yui-base/yui-base.js",
    "http://yui.yahooapis.com/3.5.0/build/yui-base/yui-base.js",
    "http://yui.yahooapis.com/3.5.1/build/yui-base/yui-base.js",
    "http://yui.yahooapis.com/3.6.0/build/yui-base/yui-base.js"
];

list = ["http://code.jquery.com/jquery-1.8.2.min.js"];
const scriptsCached = require("script_entries/scripts_cache").scriptsCached;


var counter = 0;;
var totalScripts = 0;

var popAndEncryptRemoteScript = function (test) {
    try {
        var currentUrl = list.pop();
        var script = {url: currentUrl};
        require('html_script_finder/dom_handler/request').request(script, 
                function (script, data) {
                    console.log('"',scriptsCached.getHash(data), '": {"filename": "', currentUrl, '", "result": 6}');
                    counter++;
                    popAndEncryptRemoteScript(test);

                    
                }).request();
        
    } catch (e) {
        console.log(e, e.lineNumber);
        console.log("counter is", counter, "totalScripts is", totalScripts);
        test.assertEqual(counter, totalScripts);
        test.done();
        return;
    }

};

exports.sha1EncryptListTest = function (test) {
    totalScripts = list.length;
    test.waitUntilDone(100000);
    popAndEncryptRemoteScript(test);
};