/**
 * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
 * *
 * Copyright (C) 2011, 2012 Loic J. Duros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
 *
 */

var urlHandler = require("url_handler/url_handler");

/**
 * addScriptsToPanelList
 *
 * Looks for scripts that are either valid or flagged with libreJS
 * 
 */ 
exports.addScriptsToPanelList = function (url, respData) {

  var panelRemovedScripts = [];
  var panelAcceptedScripts = [];

  // use url. remove fragment.
  url = urlHandler.removeFragment(url);
  var contents, i, reason;

  for (i = 0; i < respData.value.blocked.length; i++) {
	  // if external script only.
	  pathToUrl(respData.value.blocked[i], url);
	  panelRemovedScripts.push(respData.value.blocked[i]);
  }
  
  for (i = 0; i < respData.value.accepted.length; i++) {

	  // if external script only.
	  pathToUrl(respData.value.accepted[i], url);
	  panelAcceptedScripts.push(respData.value.accepted[i]);
  }

  return {'removed': panelRemovedScripts,
          'accepted': panelAcceptedScripts};
};


/**
 * pathToUrl
 * 
 * convert a relative path to a url.
 * 
 */
var pathToUrl = function (scriptEntry, url) {
  if (scriptEntry.inline === false) {
	  scriptEntry.url = urlHandler.resolve(url, scriptEntry.url);
  }
};
